@@ -22,7 +22,9 @@
 
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
+#include <QLoggingCategory>
 
+#include "logger.h"
 #include "passon.h"
 #include "startup/startup.h"
 #include "startup/validate.h"
@@ -45,8 +47,8 @@
 #include "scripts/metadata.h"
 #include "filefoldermodel/filefoldermodel.h"
 #include "settings/shortcuts.h"
-#include "logger.h"
 #include "scripts/handlingchromecast.h"
+#include "print/printsupport.h"
 
 #include "imageprovider/imageprovidericon.h"
 #include "imageprovider/imageproviderthumb.h"
@@ -65,14 +67,35 @@
 #include <IL/il.h>
 #endif
 
+#ifdef LIBVIPS
+#include <vips/vips8>
+#endif
+
+#ifdef VIDEOMPV
+#include "libmpv/mpvobject.h"
+#endif
+
 int main(int argc, char **argv) {
 
     // needs to be set before Q*Application is created
     QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#ifdef Q_OS_WIN
+    // This appears to avoid some glitches with OpenGL and fullscreen mode on Windows
+    QApplication::setAttribute(Qt::AA_UseOpenGLES);
+#endif
+
+    // silence the `deprecated connection' warnings
+    QLoggingCategory::setFilterRules("qt.qml.connections.warning=false");
 
     // only a single instance (by default)
     PQSingleInstance app(argc, argv);
 
+#ifdef VIDEOMPV
+    // Qt sets the locale in the QGuiApplication constructor, but libmpv
+    // requires the LC_NUMERIC category to be set to "C", so change it back.
+    std::setlocale(LC_NUMERIC, "C");
+#endif
+
     // Set app information
     QApplication::setApplicationName("PhotoQt");
     QApplication::setOrganizationName("");
@@ -100,8 +123,18 @@ int main(int argc, char **argv) {
         startup.check(true);
         startup.resetToDefaults();
         std::exit(0);
+    } else if(app.showInfo) {
+        startup.showInfo();
+        std::exit(0);
     }
 
+// only one of them will be defined at a time
+#if defined(GRAPHICSMAGICK) || defined(IMAGEMAGICK)
+    // Initialise Magick as early as possible
+    // this needs to happen BEFORE startup check as this might call into Magick
+    Magick::InitializeMagick(*argv);
+#endif
+
     // perform some startup checks
     // return 1 on updates and 2 on fresh installs
     int checker = startup.check();
@@ -128,6 +161,8 @@ int main(int argc, char **argv) {
         if(checker == 3)
             validate.validate();
 
+        PQSettings::get().update("generalVersion", VERSION);
+
     }
 
     // Get screenshots for fake transparency
@@ -138,12 +173,6 @@ int main(int argc, char **argv) {
         pix.save(QDir::tempPath() + QString("/photoqt_screenshot_%1.jpg").arg(i));
     }
 
-// only one of them will be defined at a time
-#if defined(GRAPHICSMAGICK) || defined(IMAGEMAGICK)
-    // Initialise Magick as early as possible
-    Magick::InitializeMagick(*argv);
-#endif
-
 #ifdef DEVIL
     ilInit();
 #endif
@@ -152,6 +181,10 @@ int main(int argc, char **argv) {
     FreeImage_Initialise();
 #endif
 
+#ifdef LIBVIPS
+    VIPS_INIT(argv[0]);
+#endif
+
     QQmlApplicationEngine engine;
     app.qmlEngine = &engine;
 
@@ -178,6 +211,10 @@ int main(int argc, char **argv) {
     qmlRegisterType<PQHandlingExternal>("PQHandlingExternal", 1, 0, "PQHandlingExternal");
     qmlRegisterType<PQFileFolderModel>("PQFileFolderModel", 1, 0, "PQFileFolderModel");
     qmlRegisterType<PQHandlingChromecast>("PQHandlingChromecast", 1, 0, "PQHandlingChromecast");
+    qmlRegisterType<PQPrintSupport>("PQPrintSupport", 1, 0, "PQPrintSupport");
+#ifdef VIDEOMPV
+    qmlRegisterType<PQMPVObject>("PQMPVObject", 1, 0, "PQMPVObject");
+#endif
 
     engine.rootContext()->setContextProperty("PQPassOn", &PQPassOn::get());
     engine.rootContext()->setContextProperty("PQImageFormats", &PQImageFormats::get());
@@ -202,6 +239,10 @@ int main(int argc, char **argv) {
     FreeImage_DeInitialise();
 #endif
 
+#ifdef LIBVIPS
+    vips_shutdown();
+#endif
+
     return ret;
 
 }
