@@ -22,11 +22,18 @@
 
 #include "handlingexternal.h"
 
-void PQHandlingExternal::copyTextToClipboard(QString txt) {
+PQHandlingExternal::PQHandlingExternal(QObject *parent) : QObject(parent) {
+    imageprovider = nullptr;
+}
+
+void PQHandlingExternal::copyTextToClipboard(QString txt, bool removeHTML) {
 
     DBG << CURDATE << "PQHandlingExternal::copyTextToClipboard()" << NL
         << CURDATE << "** txt = " << txt.toStdString() << NL;
 
+    if(removeHTML)
+        txt = QTextDocumentFragment::fromHtml(txt).toPlainText();
+
     QApplication::clipboard()->setText(txt, QClipboard::Clipboard);
 
 }
@@ -44,7 +51,8 @@ void PQHandlingExternal::copyToClipboard(QString filename) {
          imageprovider = new PQImageProviderFull;
 
     // set image to clipboard
-    qApp->clipboard()->setImage(imageprovider->requestImage(filename, new QSize, QSize()));
+    QImage img = imageprovider->requestImage(filename, new QSize, QSize());
+    qApp->clipboard()->setImage(img);
 
 }
 
@@ -291,10 +299,10 @@ QVariantList PQHandlingExternal::getContextMenuEntries() {
 
         QStringList thisentry;
 
-        thisentry << QString("_:_EX_:_%1").arg(command);
-        thisentry << command.split(" ").at(0);
-        thisentry << desc;
-        thisentry << (close=="1" ? "close" : "donthide");
+        thisentry << command.split(" ").at(0);  // icon
+        thisentry << command;   // executable
+        thisentry << desc;      // name
+        thisentry << close;     // close
 
         ret << thisentry;
 
@@ -306,6 +314,69 @@ QVariantList PQHandlingExternal::getContextMenuEntries() {
 
 }
 
+void PQHandlingExternal::replaceContextMenuEntriesWithAvailable() {
+
+    // These are the possible entries
+    // There will be a ' %f' added at the end of each executable.
+    QStringList m;
+    //: Used as in 'Edit with [application]'. %1 will be replaced with application name.
+    m << QApplication::translate("startup", "Edit with %1").arg("Gimp") << "gimp"
+         //: Used as in 'Edit with [application]'. %1 will be replaced with application name.
+      << QApplication::translate("startup", "Edit with %1").arg("Krita") << "krita"
+         //: Used as in 'Edit with [application]'. %1 will be replaced with application name.
+      << QApplication::translate("startup", "Edit with %1").arg("KolourPaint") << "kolourpaint"
+         //: Used as in 'Open with [application]'. %1 will be replaced with application name.
+      << QApplication::translate("startup", "Open in %1").arg("GwenView") << "gwenview"
+         //: Used as in 'Open with [application]'. %1 will be replaced with application name.
+      << QApplication::translate("startup", "Open in %1").arg("showFoto") << "showfoto"
+         //: Used as in 'Open with [application]'. %1 will be replaced with application name.
+      << QApplication::translate("startup", "Open in %1").arg("Shotwell") << "shotwell"
+         //: Used as in 'Open with [application]'. %1 will be replaced with application name.
+      << QApplication::translate("startup", "Open in %1").arg("GThumb") << "gthumb"
+         //: Used as in 'Open with [application]'. %1 will be replaced with application name.
+      << QApplication::translate("startup", "Open in %1").arg("Eye of Gnome") << "eog";
+
+    {
+        QSqlDatabase db = QSqlDatabase::database("contextmenu");
+        if(!db.open())
+            LOG << CURDATE << "PQStartup::setupFresh(): Error opening contextmenu database: " << db.lastError().text().trimmed().toStdString() << NL;
+
+        QSqlQuery query(db);
+        query.exec("DELETE FROM entries");
+        query.clear();
+
+        // Check for all entries
+        for(int i = 0; i < m.size()/2; ++i) {
+            if(checkIfBinaryExists(m[2*i+1])) {
+
+                QSqlQuery query(db);
+                query.prepare("INSERT INTO entries (command,desc,close) VALUES(:cmd,:dsc,:cls)");
+                query.bindValue(":cmd", m[2*i+1]+" %f");
+                query.bindValue(":dsc", m[2*i]);
+                query.bindValue(":cls", "0");
+                if(!query.exec())
+                    LOG << CURDATE << "PQStartup::setupFresh(): SQL error, contextmenu insert: " << query.lastError().text().trimmed().toStdString() << NL;
+
+            }
+        }
+
+    }
+
+}
+
+bool PQHandlingExternal::checkIfBinaryExists(QString exec) {
+
+#ifdef Q_OS_WIN
+    return false;
+#endif
+
+    QProcess p;
+    p.setStandardOutputFile(QProcess::nullDevice());
+    p.start("which", QStringList() << exec);
+    p.waitForFinished();
+    return p.exitCode() == 0;
+}
+
 QString PQHandlingExternal::getIconPathFromTheme(QString binary) {
 
     DBG << CURDATE << "PQHandlingExternal::getIconPathFromTheme()" << NL
@@ -489,7 +560,11 @@ void PQHandlingExternal::openInDefaultFileManager(QString filename) {
     DBG << CURDATE << "PQHandlingExternal::openInDefaultFileManager()" << NL
         << CURDATE << "** filename = " << filename.toStdString() << NL;
 
-    QDesktopServices::openUrl(QUrl("file://" + QFileInfo(filename).absolutePath()));
+#ifdef Q_OS_WIN
+    QProcess::startDetached("explorer.exe", {"/select,", QDir::toNativeSeparators(filename)});
+#else
+    QDesktopServices::openUrl(QUrl::fromLocalFile(QFileInfo(filename).absolutePath()));
+#endif
 
 }
 
@@ -525,9 +600,9 @@ void PQHandlingExternal::saveContextMenuEntries(QVariantList entries) {
 
             QVariantList entrylist = entry.toList();
 
-            const QString close = QString::number(entrylist.at(2).toInt());
+            const QString close = entrylist.at(3).toString();
             const QString cmd = entrylist.at(1).toString();
-            const QString dsc = entrylist.at(0).toString();
+            const QString dsc = entrylist.at(2).toString();
 
             if(cmd != "" && dsc != "") {
 
