@@ -20,6 +20,7 @@
  **                                                                      **
  **************************************************************************/
 
+#include <iomanip>
 #include "startup.h"
 
 PQStartup::PQStartup(QObject *parent) : QObject(parent) {
@@ -149,19 +150,6 @@ void PQStartup::importData(QString path) {
 
 }
 
-bool PQStartup::checkIfBinaryExists(QString exec) {
-
-#ifdef Q_OS_WIN
-    return false;
-#endif
-
-    QProcess p;
-    p.setStandardOutputFile(QProcess::nullDevice());
-    p.start("which", QStringList() << exec);
-    p.waitForFinished();
-    return p.exitCode() == 0;
-}
-
 void PQStartup::setupFresh(int defaultPopout) {
 
     /**************************************************************/
@@ -178,7 +166,7 @@ void PQStartup::setupFresh(int defaultPopout) {
         LOG << CURDATE << "PQStartup::setupFresh(): unable to create default imageformats database" << NL;
     else {
         QFile file(ConfigFiles::IMAGEFORMATS_DB());
-        file.setPermissions(QFile::WriteOwner|QFile::ReadOwner|QFile::ReadGroup|QFile::ReadOther);
+        file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
     }
 
     /**************************************************************/
@@ -187,7 +175,7 @@ void PQStartup::setupFresh(int defaultPopout) {
         LOG << CURDATE << "PQStartup::setupFresh(): unable to create settings database" << NL;
     else {
         QFile file(ConfigFiles::SETTINGS_DB());
-        file.setPermissions(QFile::WriteOwner|QFile::ReadOwner|QFile::ReadGroup|QFile::ReadOther);
+        file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
     }
 
     PQSettings::get().update("generalVersion", VERSION);
@@ -233,65 +221,18 @@ void PQStartup::setupFresh(int defaultPopout) {
         LOG << CURDATE << "PQStartup::Settings: unable to create shortcuts database" << NL;
     else {
         QFile file(ConfigFiles::SHORTCUTS_DB());
-        file.setPermissions(QFile::WriteOwner|QFile::ReadOwner|QFile::ReadGroup|QFile::ReadOther);
+        file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
     }
 
-
-#ifndef Q_OS_WIN
-
     /**************************************************************/
     // create default contextmenu database
     if(!QFile::copy(":/contextmenu.db", ConfigFiles::CONTEXTMENU_DB()))
         LOG << CURDATE << "PQStartup::setupFresh(): unable to create default contextmenu database" << NL;
     else {
         QFile file(ConfigFiles::CONTEXTMENU_DB());
-        file.setPermissions(QFile::WriteOwner|QFile::ReadOwner|QFile::ReadGroup|QFile::ReadOther);
+        file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
     }
 
-    // These are the possible entries
-    // There will be a ' %f' added at the end of each executable.
-    QStringList m;
-    //: Used as in 'Edit with [application]'. %1 will be replaced with application name.
-    m << QApplication::translate("startup", "Edit with %1").arg("Gimp") << "gimp"
-         //: Used as in 'Edit with [application]'. %1 will be replaced with application name.
-      << QApplication::translate("startup", "Edit with %1").arg("Krita") << "krita"
-         //: Used as in 'Edit with [application]'. %1 will be replaced with application name.
-      << QApplication::translate("startup", "Edit with %1").arg("KolourPaint") << "kolourpaint"
-         //: Used as in 'Open with [application]'. %1 will be replaced with application name.
-      << QApplication::translate("startup", "Open in %1").arg("GwenView") << "gwenview"
-         //: Used as in 'Open with [application]'. %1 will be replaced with application name.
-      << QApplication::translate("startup", "Open in %1").arg("showFoto") << "showfoto"
-         //: Used as in 'Open with [application]'. %1 will be replaced with application name.
-      << QApplication::translate("startup", "Open in %1").arg("Shotwell") << "shotwell"
-         //: Used as in 'Open with [application]'. %1 will be replaced with application name.
-      << QApplication::translate("startup", "Open in %1").arg("GThumb") << "gthumb"
-         //: Used as in 'Open with [application]'. %1 will be replaced with application name.
-      << QApplication::translate("startup", "Open in %1").arg("Eye of Gnome") << "eog";
-
-    {
-        QSqlDatabase db = QSqlDatabase::database("contextmenu");
-        if(!db.open())
-            LOG << CURDATE << "PQStartup::setupFresh(): Error opening contextmenu database: " << db.lastError().text().trimmed().toStdString() << NL;
-
-        // Check for all entries
-        for(int i = 0; i < m.size()/2; ++i) {
-            if(checkIfBinaryExists(m[2*i+1])) {
-
-                QSqlQuery query(db);
-                query.prepare("INSERT INTO entries (command,desc,close) VALUES(:cmd,:dsc,:cls)");
-                query.bindValue(":cmd", m[2*i+1]+" %f");
-                query.bindValue(":dsc", m[2*i]);
-                query.bindValue(":cls", "0");
-                if(!query.exec())
-                    LOG << CURDATE << "PQStartup::setupFresh(): SQL error, contextmenu insert: " << query.lastError().text().trimmed().toStdString() << NL;
-
-            }
-        }
-
-    }
-
-#endif
-
     /**************************************************************/
 
 
@@ -325,11 +266,6 @@ void PQStartup::performChecksAndMigrations() {
         LOG << CURDATE << "PQStartup::performChecksAndMigrations(): SQL query error: " << query.lastError().text().trimmed().toStdString() << NL;
     query.next();
 
-    // attempt to enter new format
-    if(PQImageFormats::get().enterNewFormat("jxl", "image/jxl", "JPEG XL", "img", 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, "", "jxl", true))
-
-        PQImageFormats::get().readDatabase();
-
     /**************************************************************/
 
     // migrate data
@@ -337,7 +273,75 @@ void PQStartup::performChecksAndMigrations() {
     migrateShortcutsToDb();
     migrateSettingsToDb();
 
-    PQSettings::get().update("generalVersion", VERSION);
+    // enter any new settings and shortcuts
+    renameSettings();
+    renameShortcuts();
+
+    PQValidate validate;
+    validate.validate();
+
+}
+
+// These settings changed names
+bool PQStartup::renameSettings() {
+
+    QSqlDatabase db = QSqlDatabase::database("settings");
+
+    QMap<QString,QStringList> rename;
+    rename ["QuickNavigation"] = QStringList() << "NavigationFloating" << "interface";
+    QMapIterator<QString, QStringList> i(rename);
+    while(i.hasNext()) {
+        i.next();
+
+        QString oldname = i.key();
+        QString newname = i.value().value(0);
+        QString table = i.value().value(1);
+
+        QSqlQuery query(db);
+        query.prepare(QString("UPDATE '%1' SET name=:new WHERE name=:old").arg(table));
+        query.bindValue(":new", newname);
+        query.bindValue(":old", oldname);
+        if(!query.exec()) {
+            LOG << CURDATE << "PQValidate::renameSettings(): Error updating setting name (" << oldname.toStdString() << " -> " << newname.toStdString() << "): " << query.lastError().text().trimmed().toStdString() << NL;
+            query.clear();
+            return false;
+        }
+        query.clear();
+    }
+
+    return true;
+
+}
+
+bool PQStartup::renameShortcuts() {
+
+    QSqlDatabase db = QSqlDatabase::database("shortcuts");
+
+    QMap<QString,QStringList> rename;
+    rename["__quickNavigation"] = QStringList() << "__navigationFloating" << "navigation";
+
+    QMapIterator<QString, QStringList> i(rename);
+    while(i.hasNext()) {
+        i.next();
+
+        QString oldname = i.key();
+        QString newname = i.value().value(0);
+        QString cat = i.value().value(1);
+
+        QSqlQuery query(db);
+        query.prepare("UPDATE 'builtin' SET command=:new WHERE command=:old AND category=:cat");
+        query.bindValue(":new", newname);
+        query.bindValue(":old", oldname);
+        query.bindValue(":cat", cat);
+        if(!query.exec()) {
+            LOG << CURDATE << "PQValidate::renameShortcuts(): Error updating shortcuts command (" << oldname.toStdString() << " -> " << newname.toStdString() << "): " << query.lastError().text().trimmed().toStdString() << NL;
+            query.clear();
+            return false;
+        }
+        query.clear();
+    }
+
+    return true;
 
 }
 
@@ -359,7 +363,7 @@ bool PQStartup::migrateContextmenuToDb() {
             LOG << CURDATE << "PQStartup::migrateContextmenuToDb(): unable to create contextmenu database" << NL;
         else {
             QFile file(ConfigFiles::CONTEXTMENU_DB());
-            file.setPermissions(QFile::WriteOwner|QFile::ReadOwner|QFile::ReadGroup|QFile::ReadOther);
+            file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
         }
     }
 
@@ -413,9 +417,13 @@ bool PQStartup::migrateContextmenuToDb() {
 
     }
 
-    if(!QFile::exists(QString("%1.pre-v2.5").arg(ConfigFiles::CONTEXTMENU_FILE())))
-        if(!QFile::copy(ConfigFiles::CONTEXTMENU_FILE(), QString("%1.pre-v2.5").arg(ConfigFiles::CONTEXTMENU_FILE())))
+    QString oldFile = QString("%1.pre-v2.5").arg(ConfigFiles::CONTEXTMENU_FILE());
+    if(!QFile::exists(oldFile)) {
+        if(!QFile::copy(ConfigFiles::CONTEXTMENU_FILE(), oldFile))
             LOG << CURDATE << "PQStartup::migrateContextmenuToDb(): Failed to copy old contextmenu file to 'contextmenu.pre-v2.5' filename" << NL;
+        QFile file(oldFile);
+        file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
+    }
 
     if(QFile::exists(QString("%1.pre-v2.5").arg(ConfigFiles::CONTEXTMENU_FILE())))
         if(!QFile::remove(ConfigFiles::CONTEXTMENU_FILE()))
@@ -436,7 +444,7 @@ bool PQStartup::migrateShortcutsToDb() {
             LOG << CURDATE << "PQStartup::migrateShortcutsToDb: unable to create shortcuts database" << NL;
         else {
             QFile file(ConfigFiles::SHORTCUTS_DB());
-            file.setPermissions(QFile::WriteOwner|QFile::ReadOwner|QFile::ReadGroup|QFile::ReadOther);
+            file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
         }
     }
 
@@ -591,9 +599,13 @@ bool PQStartup::migrateShortcutsToDb() {
 
     }
 
-    if(!QFile::exists(QString("%1.pre-v2.5").arg(ConfigFiles::SHORTCUTS_FILE())))
-        if(!QFile::copy(ConfigFiles::SHORTCUTS_FILE(), QString("%1.pre-v2.5").arg(ConfigFiles::SHORTCUTS_FILE())))
+    QString oldfile = QString("%1.pre-v2.5").arg(ConfigFiles::SHORTCUTS_FILE());
+    if(!QFile::exists(oldfile)) {
+        if(!QFile::copy(ConfigFiles::SHORTCUTS_FILE(), oldfile))
             LOG << CURDATE << "PQStartup::migrateShortcutsToDb(): Failed to copy old shortcuts file to 'shortcuts.pre-v2.5' filename" << NL;
+        QFile file(oldfile);
+        file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
+    }
 
     if(QFile::exists(QString("%1.pre-v2.5").arg(ConfigFiles::SHORTCUTS_FILE())))
         if(!QFile::remove(ConfigFiles::SHORTCUTS_FILE()))
@@ -614,7 +626,7 @@ bool PQStartup::migrateSettingsToDb() {
             LOG << CURDATE << "PQStartup::Settings: unable to create settings database" << NL;
         else {
             QFile file(ConfigFiles::SETTINGS_DB());
-            file.setPermissions(QFile::WriteOwner|QFile::ReadOwner|QFile::ReadGroup|QFile::ReadOther);
+            file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
         }
     } else {
         if(file.exists())
@@ -766,7 +778,6 @@ bool PQStartup::migrateSettingsToDb() {
     // category: Metadata Element
     /******************************************************/
     conversions.insert("MetadataEnableHotEdge", QStringList() << "metadata" << "ElementHotEdge");
-    conversions.insert("MetadataOpacity",       QStringList() << "metadata" << "ElementOpacity");
     conversions.insert("MetadataWindowWidth",   QStringList() << "metadata" << "ElementWidth");
     /******************************************************/
     // category: People Tags in Metadata
@@ -924,9 +935,13 @@ bool PQStartup::migrateSettingsToDb() {
         LOG << CURDATE << "PQStartup::migrateSettingsToDb(): SQL error:  " << query.lastError().text().trimmed().toStdString() << NL;
     }
 
-    if(!QFile::exists(QString("%1.pre-v2.5").arg(ConfigFiles::SETTINGS_FILE())))
-        if(!QFile::copy(ConfigFiles::SETTINGS_FILE(), QString("%1.pre-v2.5").arg(ConfigFiles::SETTINGS_FILE())))
+    QString oldfile = QString("%1.pre-v2.5").arg(ConfigFiles::SETTINGS_FILE());
+    if(!QFile::exists(oldfile)) {
+        if(!QFile::copy(ConfigFiles::SETTINGS_FILE(), oldfile))
             LOG << CURDATE << "PQStartup::migrateSettingsToDb(): Failed to copy old settings file to 'settings.pre-v2.5' filename" << NL;
+        QFile file(oldfile);
+        file.setPermissions(file.permissions()|QFileDevice::WriteOwner);
+    }
 
     if(QFile::exists(QString("%1.pre-v2.5").arg(ConfigFiles::SETTINGS_FILE())))
         if(!QFile::remove(ConfigFiles::SETTINGS_FILE()))
@@ -937,3 +952,11 @@ bool PQStartup::migrateSettingsToDb() {
     return true;
 
 }
+
+void PQStartup::showInfo() {
+
+    LOG << NL << "PhotoQt configuration:" << NL << NL
+        << PQHandlingGeneral::getConfigInfo().toStdString()
+        << NL;
+
+}
